

use BDDPanel,clear


/******************************************/
*********** Panel Data   ******************/
/******************************************/

egen familyidnum = group(familyid)
duplicates tag familyidnum year, gen(dupc)

drop if dupc
drop dupc

drop if familyidnum==.
xtset familyidnum year



*** time invariant weights => individual mean over period

* wtcsld26 = weights accounting for specificity in 1993-1995 and 2011 (only one panel)
{
bysort personidwi : egen poids_indwi = mean(wtcsld26wi)
bysort personidhu : egen poids_indhu = mean(wtcsld26hu)
bysort familyidnum : egen poids_couplewi = mean(wtcsld26wi)
bysort familyidnum : egen poids_couplehu = mean(wtcsld26hu)
}



/*********************************************************/
*********** Construction of variables  ******************/
/*********************************************************/



* presence of children (CAUTIOUS = pb men before 1999 --- keep observation for women)
{
gen has_childwi = ( chdb16wi != 0 & chdb16wi != . ) 
gen has_childhu = ( chdb16hu != 0 & chdb16hu != . ) 
replace has_childhu = 1 if has_childwi == 1 & statehu <= 2 & year < 1999
replace has_childhu = . if personidhu == ""
replace has_childwi = . if personidwi == ""


* number of children
foreach var in "wi" "hu" {
gen onechild`var'=(chdbar16`var'==1)
gen twochild`var'=(chdbar16`var'==2)
gen morethan2child`var'=(chdbar16`var'> 2 & chdbar16`var' != .)
}
replace onechildhu = 1       if onechildwi == 1       & statehu <= 2 & year < 1999
replace twochildhu = 1       if twochildwi == 1       & statehu <= 2 & year < 1999
replace morethan2childhu = 1 if morethan2childwi == 1 & statehu <= 2 & year < 1999
}


/**********************************************************************/
/*************** Treatment variable (NOV 2018) ************************/
/**********************************************************************/


foreach q in "wi" "hu" {
gen prov_TN_`q'  = (pvreg25`q' == 10)
gen prov_PEI_`q' = (pvreg25`q' == 11)
gen prov_NE_`q'  = (pvreg25`q' == 12)
gen prov_NB_`q'  = (pvreg25`q' == 13)
gen prov_QUE_`q' = (pvreg25`q' == 24)
gen prov_ONT_`q' = (pvreg25`q' == 35) 
gen prov_MAN_`q' = (pvreg25`q' == 46)
gen prov_SAS_`q' = (pvreg25`q' == 47)
gen prov_ALB_`q' = (pvreg25`q' == 48)
gen prov_CB_`q'  = (pvreg25`q' == 59)
}

* ALIMONY REFORM
gen after_reffed_TN  = (year >= 1990)
gen after_reffed_PEI = (year >= 1995)
gen after_reffed_NE  = (year >= 1989)
gen after_reffed_NB  = (year >= 1980)
gen after_reffed_ONT = (year >= 1978)
gen after_reffed_MAN = (year >= 1983)
gen after_reffed_MAN2= (year >= 2001)
gen after_reffed_SAS = (year >= 1990)
gen after_reffed_ALB = (year >= 1999)
gen after_reffed_CB  = (year >= 1972)

* MARRIAGE LIKE REFORM
gen after_refeg_MAN = (year >= 2004)
gen after_refeg_SAS = (year >= 1997)


* YEAR OF REFORMS
foreach q in "wi" "hu"{
	gen year_reffed`q' =  .
	replace year_reffed`q' = 1990 if pvreg25`q' == 10
	replace year_reffed`q' = 1995 if pvreg25`q' == 11
	replace year_reffed`q' = 1989 if pvreg25`q' == 12
	replace year_reffed`q' = 1980 if pvreg25`q' == 13
	replace year_reffed`q' = 1978 if pvreg25`q' == 35
	replace year_reffed`q' = 1983 if pvreg25`q' == 46
	replace year_reffed`q' = 1990 if pvreg25`q' == 47
	replace year_reffed`q' = 1999 if pvreg25`q' == 48
	replace year_reffed`q' = 1972 if pvreg25`q' == 59

	gen year_refeg`q' =  .
	replace year_refeg`q' = 2004 if pvreg25`q' == 46
	replace year_refeg`q' = 1997 if pvreg25`q' == 47
}

* MINIMAL DURATION TO BE ELIGIBLE
gen durmin_TN  = 2 
gen durmin_PEI = 3
gen durmin_NE  = 2
gen durmin_NB  = 3
gen durmin_ONT = 3
gen durmin_MAN = 5
gen durmin_MAN2= 3
gen durmin_SAS = 2
gen durmin_ALB = 3
gen durmin_CB  = 2 

foreach q in "wi" "hu"{
gen durmin`q' = .
replace durmin`q' =  durmin_TN if pvreg25`q' == 10
replace durmin`q' =  durmin_PEI if pvreg25`q' == 11
replace durmin`q' =  durmin_NE if pvreg25`q' == 12
replace durmin`q' =  durmin_NB if pvreg25`q' == 13
replace durmin`q' =  durmin_ONT if pvreg25`q' == 35
replace durmin`q' =  durmin_MAN if pvreg25`q' == 46 & year > 1983 & year <= 2001
replace durmin`q' =  durmin_MAN2 if pvreg25`q' == 46 & year > 2001
replace durmin`q' =  durmin_SAS if pvreg25`q' == 47
replace durmin`q' =  durmin_ALB if pvreg25`q' == 48
replace durmin`q' =  durmin_CB if pvreg25`q' == 59
}

* indicates whether minimal duration is reached
**** alimony
foreach q in "wi" "hu"{
gen durok`q'_reffed_TN  = (duree_couple`q' >= durmin_TN   & duree_couple`q'   !=.)
gen durok`q'_reffed_PEI = (duree_couple`q' >= durmin_PEI  & duree_couple`q'  !=.)
gen durok`q'_reffed_NE  = (duree_couple`q' >= durmin_NE   & duree_couple`q'   !=.)
gen durok`q'_reffed_NB  = (duree_couple`q' >= durmin_NB   & duree_couple`q'   !=.)
gen durok`q'_reffed_ONT = (duree_couple`q' >= durmin_ONT  & duree_couple`q'  !=.)
gen durok`q'_reffed_MAN = (duree_couple`q' >= durmin_MAN  & duree_couple`q'  !=.)
gen durok`q'_reffed_MAN2= (duree_couple`q' >= durmin_MAN2 & duree_couple`q' !=.)
gen durok`q'_reffed_SAS = (duree_couple`q' >= durmin_SAS  & duree_couple`q'  !=.)
gen durok`q'_reffed_ALB = (duree_couple`q' >= durmin_ALB  & duree_couple`q'  !=.)
gen durok`q'_reffed_CB  = (duree_couple`q' >= durmin_CB   & duree_couple`q'   !=.)
}

**** marriage like
foreach q in "wi" "hu"{
gen durok`q'_refeg_MAN = (duree_couple`q' >= 3 & duree_couple`q' !=.)
gen durok`q'_refeg_SAS = (duree_couple`q' >= 2 & duree_couple`q' !=.)
}

* reduced threshold for couples with children
gen durmin_child_TN   = 1 
gen durmin_child_PEI  = 0
gen durmin_child_NE   = 2
gen durmin_child_NB   = 1
gen durmin_child_ONT  = 0
gen durmin_child_MAN  = 5
gen durmin_child_MAN2 = 1
gen durmin_child_SAS  = 0
gen durmin_child_SAS2 = 2
gen durmin_child_ALB  = 0
gen durmin_child_CB   = 2 


foreach q in "wi" "hu"{
gen durmin_child`q' = .
replace durmin_child`q' =  durmin_child_TN if pvreg25`q' == 10
replace durmin_child`q' =  durmin_child_PEI if pvreg25`q' == 11
replace durmin_child`q' =  durmin_child_NE if pvreg25`q' == 12
replace durmin_child`q' =  durmin_child_NB if pvreg25`q' == 13
replace durmin_child`q' =  durmin_child_ONT if pvreg25`q' == 35
replace durmin_child`q' =  durmin_child_MAN if pvreg25`q' == 46 & year > 1983 & year <= 2001
replace durmin_child`q' =  durmin_child_MAN2 if pvreg25`q' == 46 & year > 2001
replace durmin_child`q' =  durmin_child_SAS if pvreg25`q' == 47
replace durmin_child`q' =  durmin_child_ALB if pvreg25`q' == 48
replace durmin_child`q' =  durmin_child_CB if pvreg25`q' == 59
}



* dummies shorten period if children 
foreach q in "wi" "hu"{
gen durokchild`q'_TN  = (duree_couple`q' >= durmin_child_TN   & duree_couple`q' !=.)
gen durokchild`q'_PEI = (duree_couple`q' >= durmin_child_PEI  & duree_couple`q' !=.)
gen durokchild`q'_NE  = (duree_couple`q' >= durmin_child_NE   & duree_couple`q' !=.)
gen durokchild`q'_NB  = (duree_couple`q' >= durmin_child_NB   & duree_couple`q' !=.)
gen durokchild`q'_ONT = (duree_couple`q' >= durmin_child_ONT  & duree_couple`q' !=.)
gen durokchild`q'_MAN = (duree_couple`q' >= durmin_child_MAN  & duree_couple`q' !=.)
gen durokchild`q'_MAN2= (duree_couple`q' >= durmin_child_MAN2 & duree_couple`q' !=.)
gen durokchild`q'_SAS = (duree_couple`q' >= durmin_child_SAS  & duree_couple`q' !=.)
gen durokchild`q'_SAS2= (duree_couple`q' >= durmin_child_SAS2 & duree_couple`q' !=.)
gen durokchild`q'_ALB = (duree_couple`q' >= durmin_child_ALB  & duree_couple`q' !=.)
gen durokchild`q'_CB  = (duree_couple`q' >= durmin_child_CB   & duree_couple`q' !=.)
}


****** TREATMENT VARIABLE ******

**** MARRIAGE LIKE TREATMENT (Manitoba et Saska)
foreach q in "wi" "hu"{
* without children    	
gen reg_egal`q' = .
replace reg_egal`q' = 0 if duree_couple`q' != .
replace reg_egal`q' = 1 if prov_MAN_`q'==1 & after_refeg_MAN==1 & durok`q'_refeg_MAN==1
replace reg_egal`q' = 1 if prov_SAS_`q'==1 & after_refeg_SAS==1 & durok`q'_refeg_SAS==1

* with children
gen reg_egal_child`q' = .
replace reg_egal_child`q' = 0 if duree_couple`q' != .
replace reg_egal_child`q' = 1 if prov_MAN_`q'==1 & durokchild`q'_MAN2==1 & after_refeg_MAN==1 & has_child`q'==1
replace reg_egal_child`q' = 1 if prov_SAS_`q'==1 & durokchild`q'_SAS2==1 & after_refeg_SAS==1 & has_child`q'==1
}

**** ALIMONY TREATMENT
foreach q in "wi" "hu"{
***** No child
gen reg_fed`q' = .
replace reg_fed`q' = 0 if duree_couple`q' != .
replace reg_fed`q' = 1 if prov_TN_`q'==1  & durok`q'_reffed_TN  == 1 & after_reffed_TN   == 1
replace reg_fed`q' = 1 if prov_PEI_`q'==1 & durok`q'_reffed_PEI == 1 & after_reffed_PEI  == 1
replace reg_fed`q' = 1 if prov_NE_`q' ==1 & durok`q'_reffed_NE  == 1 & after_reffed_NE   == 1
replace reg_fed`q' = 1 if prov_NB_`q'==1  & durok`q'_reffed_NB  == 1 & after_reffed_NB   == 1
replace reg_fed`q' = 1 if prov_ONT_`q'==1 & durok`q'_reffed_ONT == 1 & after_reffed_ONT  == 1
replace reg_fed`q' = 1 if prov_MAN_`q'==1 & durok`q'_reffed_MAN == 1 & after_reffed_MAN  == 1 & after_reffed_MAN2 == 0
replace reg_fed`q' = 1 if prov_MAN_`q'==1 & durok`q'_reffed_MAN2== 1 & after_reffed_MAN2 == 1
replace reg_fed`q' = 1 if prov_SAS_`q'==1 & durok`q'_reffed_SAS == 1 & after_reffed_SAS  == 1 
replace reg_fed`q' = 1 if prov_ALB_`q'==1 & durok`q'_reffed_ALB == 1 & after_reffed_ALB  == 1
replace reg_fed`q' = 1 if prov_CB_`q'==1  & durok`q'_reffed_CB  == 1 & after_reffed_CB   == 1


***** With children
gen reg_child`q' = .
replace reg_child`q' = 0 if duree_couple`q' != .
replace reg_child`q' = 1 if prov_TN_`q'==1  & durokchild`q'_TN   == 1 & after_reffed_TN   == 1 & has_child`q' == 1
replace reg_child`q' = 1 if prov_PEI_`q'==1 & durokchild`q'_PEI  == 1 & after_reffed_PEI  == 1 & has_child`q' == 1
replace reg_child`q' = 1 if prov_NE_`q'==1  & durokchild`q'_NE   == 1 & after_reffed_NE   == 1 & has_child`q' == 1 
replace reg_child`q' = 1 if prov_NB_`q'==1  & durokchild`q'_NB   == 1 & after_reffed_NB   == 1 & has_child`q' == 1
replace reg_child`q' = 1 if prov_ONT_`q'==1 & durokchild`q'_ONT  == 1 & after_reffed_ONT  == 1 & has_child`q' == 1
replace reg_child`q' = 1 if prov_MAN_`q'==1 & durokchild`q'_MAN  == 1 & after_reffed_MAN  == 1 & has_child`q' == 1
replace reg_child`q' = 1 if prov_MAN_`q'==1 & durokchild`q'_MAN2 == 1 & after_reffed_MAN2 == 1 & has_child`q' == 1
replace reg_child`q' = 1 if prov_SAS_`q'==1 & durokchild`q'_SAS  == 1 & after_reffed_SAS  == 1 & has_child`q' == 1
replace reg_child`q' = 1 if prov_ALB_`q'==1 & durokchild`q'_ALB  == 1 & after_reffed_ALB  == 1 & has_child`q' == 1
replace reg_child`q' = 1 if prov_CB_`q'==1  & durokchild`q'_CB   == 1 & after_reffed_CB   == 1 & has_child`q' == 1

}


* ELIGIBILITY STATUS
foreach q in "wi" "hu"{
* alimony     
gen reg_cilw`q'     = (reg_fed`q' == 1 | reg_child`q' == 1) 
replace reg_cilw`q' = . if duree_couple`q' == .
* marriage like
gen regeg_cilw`q'     = (reg_egal`q' == 1 | reg_egal_child`q' == 1) 
replace regeg_cilw`q' = . if duree_couple`q' == .
}





/* **************************************************/
******** fixed effects *********
/* **************************************************/

* duration
foreach q in "wi" "hu"{
	forv k = 0/10{
		gen d_`k'y_`q' = (duree_couple`q'==`k')
	}
	replace d_10y_`q' = 1 if (duree_couple`q'>10 & duree_couple`q'!=.)
}

* year
forv k = 1993/2011{
gen y_`k' = (year==`k')
}

/* **************************************************/
******** fixed effects interacted with dummy indicating children *********
/* **************************************************/

* child*duration
foreach q in "wi" "hu"{
forv k = 0/10{
gen d_`k'y_c_`q' = d_`k'y_`q'*has_child`q'
}
}

* child*prov  (Quebec has baseline)
foreach q in "wi" "hu"{
gen prov_TN_child_`q'  = prov_TN_`q'*has_child`q'
gen prov_PEI_child_`q' = prov_PEI_`q'*has_child`q'
gen prov_NE_child_`q'  = prov_NE_`q'*has_child`q'
gen prov_NB_child_`q'  = prov_NB_`q'*has_child`q'
gen prov_ONT_child_`q' = prov_ONT_`q'*has_child`q'
gen prov_MAN_child_`q' = prov_MAN_`q'*has_child`q'
gen prov_SAS_child_`q' = prov_SAS_`q'*has_child`q'
gen prov_ALB_child_`q' = prov_ALB_`q'*has_child`q'
gen prov_CB_child_`q'  = prov_CB_`q'*has_child`q'
}

* child*year
foreach q in "wi" "hu"{
forv k = 1993/2011{
	gen y_`k'_c_`q' = y_`k'*has_child`q'
}
}


****************************************************************************************
**** Variables indicating that the couple gets married, and if the couple breaks up
****************************************************************************************

foreach q in "wi" "hu"{

so pvreg25`q' year duree_couple`q'
tempfile panel
save `panel',replace 

gen getmarriedthisyear`q'  = (personid`q' == personid`q'[_n-1] & (state`q' == 1) & (state`q'[_n-1] == 2))
replace getmarriedthisyear`q' = . if state`q' == .
replace getmarriedthisyear`q' = . if personid`q' == ""

gen breakup`q'  = (personid`q' == personid`q'[_n+1] & (state`q' == 1|state`q' == 2) & (state`q'[_n+1] != 1 & state`q'[_n+1] != 2))
replace breakup`q' = . if state`q' == .
replace breakup`q' = . if personid`q' == ""
}


*****************************************************************************************************
******** VARIABLES indidicating whether the couple was formed before of after the reform ********
*****************************************************************************************************

foreach q in "hu" "wi"{
gen year_formcouple_`q' = year - duree_couple`q'
}

foreach q in "hu" "wi"{
bys familyid : egen min_year_formcouple_`q' = min(year_formcouple_`q')
bys familyid : egen max_year_formcouple_`q' = max(year_formcouple_`q')
}


* formation couple after or before reforms
foreach q in "hu" "wi"{
    
*alimony
gen formcouple_aftregfed_`q' = .
replace formcouple_aftregfed_`q' = 0 if year_formcouple_`q' != .
replace formcouple_aftregfed_`q' = 1 if (year_formcouple_`q' > year_reffed`q' & year_formcouple_`q' != . & year_reffed`q' != .)

gen formcouple_befregfed_`q' = .
replace formcouple_befregfed_`q' = 1 - formcouple_aftregfed_`q'  if formcouple_aftregfed_`q' != .

*marriage like
gen formcouple_aftregeg_`q' = .
replace formcouple_aftregeg_`q' = 0 if year_formcouple_`q' != .
replace formcouple_aftregeg_`q' = 1 if (year_formcouple_`q' > year_refeg`q' & year_formcouple_`q' != . & year_refeg`q' != .)

gen formcouple_befregeg_`q' = .
replace formcouple_befregeg_`q' = 1 -  formcouple_aftregeg_`q'   if formcouple_aftregeg_`q' != .
}

* eligible before or after reform

* alimony
foreach q in "hu" "wi"{
gen eligibleafter_fed_`q' = .
replace  eligibleafter_fed_`q' = 0 if year_formcouple_`q' != .
replace  eligibleafter_fed_`q' = 1 if year_formcouple_`q' >=  year_reffed`q'-durmin`q' & year_formcouple_`q' != . & year_reffed`q' != . 

gen eligiblebefore_fed_`q' = .
replace  eligiblebefore_fed_`q' = 1 - eligibleafter_fed_`q'  if eligibleafter_fed_`q' != .

* marriage like
gen eligibleafter_egal_`q' = .
replace eligibleafter_egal_`q' = 0 if year_formcouple_`q' != .
replace eligibleafter_egal_`q' = 1 if year_formcouple_`q' >=  year_refeg`q'-durmin`q' & year_formcouple_`q' != . & year_refeg`q' != .

gen eligiblebefore_egal_`q' = .
replace eligiblebefore_egal_`q' = 1 - eligibleafter_egal_`q' if eligibleafter_egal_`q' != .
}


* variables indicating whether the couples had a child in duration 0 or 1, because they could be eligible before.
gen has_childhu_01 = (has_childhu == 1 & inlist(duree_couplehu,0,1))
bys familyidnum : egen s_has_childhu_01 = sum(has_childhu_01)
recode s_has_childhu_01 (2/max = 1)
drop has_childhu_01
ren s_has_childhu_01 has_childhu_01

gen has_childwi_01 = (has_childwi == 1 & inlist(duree_couplewi,0,1))
bys familyidnum : egen s_has_childwi_01 = sum(has_childwi_01)
recode s_has_childwi_01 (2/max = 1)
drop has_childwi_01
ren s_has_childwi_01 has_childwi_01

* variables indicating whether couples were eligible at reform or after (caught and non caught)
gen couple_fedwi_bef1 = ((formcouple_befregfed_wi == 1 & eligiblebefore_fed_wi == 1) | (formcouple_befregfed_wi == 1 & eligiblebefore_fed_wi == 0 & has_childwi_01 == 1 ) )
gen couple_fedwi_bef2 =  (formcouple_befregfed_wi == 1 & eligiblebefore_fed_wi == 0 & has_childwi_01 == 0)
gen couple_fedwi_aft  = (formcouple_aftregfed_wi==1)
gen couple_fedwi_noncaught = couple_fedwi_bef2 + couple_fedwi_aft

gen couple_egwi_bef1 = ((formcouple_befregeg_wi == 1 & eligiblebefore_egal_wi == 1) | (formcouple_befregeg_wi == 1 & eligiblebefore_egal_wi == 0 & has_childwi_01 == 1 ) )
gen couple_egwi_bef2 = (formcouple_befregeg_wi == 1 & eligiblebefore_egal_wi == 0 & has_childwi_01 == 0)
gen couple_egwi_aft  = (formcouple_aftregeg_wi == 1)
gen couple_egwi_noncaught = couple_egwi_bef2 + couple_egwi_aft

gen couple_fedhu_bef1 = ((formcouple_befregfed_hu == 1 & eligiblebefore_fed_hu == 1) | (formcouple_befregfed_hu == 1 & eligiblebefore_fed_hu == 0 & has_childhu_01 == 1 ) )
gen couple_fedhu_bef2 = (formcouple_befregfed_hu == 1  & eligiblebefore_fed_hu == 0 & has_childhu_01 == 0)
gen couple_fedhu_aft  = (formcouple_aftregfed_hu==1)
gen couple_fedhu_noncaught = couple_fedhu_bef2 + couple_fedhu_aft

gen couple_eghu_bef1 = ((formcouple_befregeg_hu == 1 & eligiblebefore_egal_hu == 1) | (formcouple_befregeg_hu == 1 & eligiblebefore_egal_hu == 0 & has_childhu_01 == 1 ) )
gen couple_eghu_bef2 = (formcouple_befregeg_hu == 1 & eligiblebefore_egal_hu == 0 & has_childhu_01 == 0)
gen couple_eghu_aft  = (formcouple_aftregeg_hu == 1)
gen couple_eghu_noncaught = couple_eghu_bef2 + couple_eghu_aft


gen reg_cilwwi_bef1   = reg_cilwwi*couple_fedwi_bef1
gen reg_cilwwi_noncaught = reg_cilwwi*couple_fedwi_noncaught

gen regeg_cilwwi_bef1 = regeg_cilwwi*couple_egwi_bef1
gen regeg_cilwwi_noncaught  = regeg_cilwwi*couple_egwi_noncaught

gen reg_cilwhu_bef1   = reg_cilwhu*couple_fedhu_bef1
gen reg_cilwhu_noncaught   = reg_cilwhu*couple_fedhu_noncaught

gen regeg_cilwhu_bef1 = regeg_cilwhu*couple_eghu_bef1
gen regeg_cilwhu_noncaught = regeg_cilwhu*couple_eghu_noncaught



****************** 28 Janvier 2021 **************************
***************** Variables REFORM *************************

foreach q in "wi" "hu" {
***** treatment : marriage like reform for ALB et PEI
gen reform_fed`q' = 0
replace reform_fed`q' = 1 if year >= year_reffed`q'
replace reform_fed`q' = . if personid`q' == ""

***** treatment : marriage like reform for MANI and SASK
gen reform_egal`q' = 0
replace reform_egal`q' = 1 if year >= year_refeg`q'
replace reform_egal`q' = . if personid`q' == ""
}



**********  Other variables, more cleaning  *************************
**********   Earnings and number of hours worked *************************

* negative earnings are uncommon, changed for missing 
replace earng42wi = . if earng42wi <0
replace earng42hu = . if earng42hu <0

foreach var in "wi" "hu" {

gen actif`var'       = (alhrp28`var'>0 & alhrp28`var' !=.)
replace actif`var'   = . if alhrp28`var' ==.
gen statempincon`var' = (alfst28`var' == "97" | alfst28`var' == "99" )

*not employed = inactive or unemployed all year, or mix both
gen notemployed`var'     = (alfst28`var' == "02" | alfst28`var' == "03"| alfst28`var' == "06") 

* missing if unclear employment status
replace notemployed`var' = .  if statempincon`var'== 1
replace alhrp28`var' = .  if statempincon`var'== 1
replace earng42`var' = .  if statempincon`var'== 1
}



* winsorization for the top 1% of earnings and hours
foreach sex in "wi" "hu" {
	forv k = 1993/2011{

	centile earng42`sex' if year ==`k' , centile(99)
	replace earng42`sex' = r(c_1) if  (earng42`sex'>= r(c_1) & earng42`sex'!=.)  & year ==`k'

	centile alhrp28`sex' if year ==`k', centile(99)
	replace alhrp28`sex' = r(c_1) if  (alhrp28`sex'>= r(c_1) & alhrp28`sex'!=. )  & year ==`k'

	}
}


save BDDPanel2, replace




* import Provincial CPI
import excel "T:\Projet 4375\Data\IPC_Canada_1993-2011.xlsx", sheet("Feuil1") firstrow clear
keep year pvreg25 cpi
gen pvreg25wi = pvreg25
rename pvreg25 pvreg25hu
save cpi, replace

use BDDPanel2, clear

merge m:1 year pvreg25wi  using  cpi
rename cpi cpiwi
drop _merge
merge m:1 year pvreg25hu  using  cpi
rename cpi cpihu
drop _merge

destring cpi*,replace

gen incomewi = earng42wi/cpiwi*100 
gen incomehu = earng42hu/cpihu*100 

gen hourswi = alhrp28wi
gen hourshu = alhrp28hu

replace hourswi =  alhrwk28wi if alhrp28wi == 0 & incomewi >0 & alhrwk28wi > 0 & alhrwk28wi < 9997
replace hourshu =  alhrwk28hu if alhrp28hu == 0 & incomehu >0 & alhrwk28hu > 0 & alhrwk28hu < 9997

*** dummy indicating individuals working full time (following SLID recommendations)
gen workingfthu = (hourshu >= 1800 & hourshu != .)
replace workingfthu = . if  hourshu == .
gen workingftwi = (hourswi >= 1800 & hourswi != .)
replace workingftwi = . if  hourswi == .



* variables on wife position within households
gen wifeshareinc  = incomewi/(incomehu+incomewi)
gen wifesharehour = hourswi/(hourshu+hourswi)



* identify migrants across provinces (all)
bysort familyidnum : egen change = max(pvreg25hu) 
bysort familyidnum : egen change1 = mean(pvreg25hu) 
bysort familyidnum : egen change2 = min(pvreg25hu) 
gen migrant_prov_hu = (change !=change2)
replace migrant_prov_hu = . if pvreg25hu == .
drop change change1 change2 
bysort familyidnum : egen change = max(pvreg25wi) 
bysort familyidnum : egen change1 = mean(pvreg25wi) 
bysort familyidnum : egen change2 = min(pvreg25wi) 
gen migrant_prov_wi = (change !=change2)
replace migrant_prov_wi = . if pvreg25wi == .
drop change change1 change2 


* identify migrants (individuals --- for counting)
bysort personidhu : egen change = max(pvreg25hu) 
bysort personidhu : egen change1 = mean(pvreg25hu) 
bysort personidhu : egen change2 = min(pvreg25hu) 
gen migrant_prov2_hu = (change !=change2)
replace migrant_prov2_hu = . if pvreg25hu == .
drop change change1 change2 
bysort personidwi : egen change = max(pvreg25wi) 
bysort personidwi : egen change1 = mean(pvreg25wi) 
bysort personidwi : egen change2 = min(pvreg25wi) 
gen migrant_prov2_wi = (change !=change2)
replace migrant_prov2_wi = . if pvreg25wi == .
drop change change1 change2 

* identify migrants v2
gen pvreg25fam = .
replace pvreg25fam = pvreg25hu if (pvreg25hu == pvreg25wi) & pvreg25hu != .
replace pvreg25fam = pvreg25hu if pvreg25wi == . & pvreg25hu != .
replace pvreg25fam = pvreg25wi if pvreg25wi != . & pvreg25hu == .

bysort familyidnum : egen change = max(pvreg25fam) 
bysort familyidnum : egen change1 = mean(pvreg25fam) 
bysort familyidnum : egen change2 = min(pvreg25fam) 
gen migrant_prov_fam = (change !=change2)
replace migrant_prov_fam = . if pvreg25fam == .
drop change change1 change2 


* check whether noearnings and no hours worked are consistent
gen incomehu0 = (incomehu == 0)
replace incomehu0 = . if incomehu == .
gen incomewi0 = (incomewi == 0)
replace incomewi0 = . if incomewi == .

gen hourshu0 = (hourshu == 0)
replace hourshu0 = . if hourshu == .
gen hourswi0 = (hourswi == 0)
replace hourswi0 = . if hourswi == .

gen incoherencehu = (incomehu0 == 1 & hourshu0 == 0 | incomehu0 == 0 & hourshu0 == 1)
gen incoherencewi = (incomewi0 == 1 & hourswi0 == 0 | incomewi0 == 0 & hourswi0 == 1)


* log transformation 
g lnhourshu = ln(hourshu)
g lnhourswi = ln(hourswi)
g lnincomehu = ln(incomehu)
g lnincomewi = ln(incomewi)

* number of hours worked (intensive labor supply)
gen hours_inthu = hourshu 
replace hours_inthu = . if hourshu == 0
gen hours_intwi = hourswi 
replace hours_intwi = . if hourswi == 0
gen income_inthu = incomehu 
replace income_inthu = . if incomehu == 0
gen income_intwi = incomewi 
replace income_intwi = . if incomewi == 0

* indicates whether no earnings 
gen noearningswi = (incomewi == 0)
gen noearningshu = (incomehu == 0)

* number of active weeks
foreach q in "hu" "wi"{ 
gen wkactif`q' = wksem28`q' + wksuem28`q'
gen wkempl`q' = wksem28`q' 
}



gen agewi_sq = age26wi^2
gen agehu_sq = age26hu^2


save BDDPanel2, replace




************************************ DATA CLEANING FOR REGRESSION USING COUPLES (SELECTION) ************************************

* GOAL: create variables at the couple level (keep observations for male partner if only male partner observed, female partner if only female partner observed or combine information if both observed)


use BDDPanel2, clear 

gen     state = .
replace state = statehu if statehu != . & statewi == . 
replace state = statewi if statewi != . & statehu == .
replace state = . if statewi != statehu &  statewi != . &  statehu != .

gen married = .
replace married = 1 if statehu == 1 & statehu != .
replace married = 0 if statehu != 1 & statehu != .
replace married = 1 if statewi == 1 & statewi != .
replace married = 0 if statewi != 1 & statewi != .
replace married = . if statewi != . &  statehu != . & (statewi != 1 & statehu == 1 | statewi == 1 & statehu != 1)  

gen cohab = .
replace cohab = 1 if statehu == 2 & statehu != .
replace cohab = 0 if statehu != 2 & statehu != .
replace cohab = 1 if statewi == 2 & statewi != .
replace cohab = 0 if statewi != 2 & statewi != .
replace cohab = . if statewi != . & statehu != . & (statewi != 2 & statehu == 2 | statewi == 2 & statehu != 2)  


foreach var in pvreg25 panel21 has_child duree_couple reform_fed reform_egal educ age26 young2 young3 old allage poids_ind{
gen `var'     = `var'hu if statehu != .
replace `var' = `var'wi if statehu == . &  statewi != .
}

* sex of respondent
gen sex     = 1 if statehu != . &  statewi == .
replace sex = 2 if statehu == . &  statewi != .
replace sex = 0 if statehu != . &  statewi != .


* province specific trend
foreach p in 10 11 12 13 24 35 46 47 48 59 {
		gen prov_`p'_y = (pvreg25 == `p')*year
	}
	
* couple weights
gen     poids_couple = poids_couplehu if statehu != .
replace poids_couple = poids_couplewi if statehu == . &  statewi != .

	
foreach q in "hu" "wi"{
gen after_reffed`q' = 0
replace after_reffed`q' = 1 if year >= year_reffed`q'
gen after_refeg`q' = 0
replace after_refeg`q' = 1 if year >= year_refeg`q'
}	



************************************ when both partners are observed

* variables that should be identical 
foreach var in pvreg25 has_child duree_couple reform_fed reform_egal {
replace `var' = . if `var'hu != `var'wi & `var'hu != . & `var'wi != .
}

	
foreach var in eligiblebefore_fed_  formcouple_befregfed_  formcouple_aftregfed_  eligiblebefore_egal_  formcouple_befregeg_  formcouple_aftregeg_  getmarriedthisyear breakup after_reffed after_refeg reg_cilw regeg_cilw{
gen `var'     = `var'hu if statehu != . &  statewi == .
replace `var' = `var'wi if statehu == . &  statewi != .
replace `var' = `var'wi if `var'hu == `var'wi & statehu != . &  statewi != .
replace `var' = .       if `var'hu != `var'wi & statehu != . &  statewi != .
}

foreach var in couple_fed couple_eg reg_cilw regeg_cilw{
gen `var'_bef1     = `var'hu_bef1 if statehu != . &  statewi == .
replace `var'_bef1 = `var'wi_bef1 if statehu == . &  statewi != .
replace `var'_bef1 = `var'wi_bef1 if `var'hu_bef1 == `var'wi_bef1 & statehu != . &  statewi != .
replace `var'_bef1 = .            if `var'hu_bef1 != `var'wi_bef1 & statehu != . &  statewi != .

gen `var'_noncaught     = `var'hu_noncaught if statehu != . &  statewi == .
replace `var'_noncaught = `var'wi_noncaught if statehu == . &  statewi != .
replace `var'_noncaught = `var'wi_noncaught if `var'hu_noncaught == `var'wi_noncaught & statehu != . &  statewi != .
replace `var'_noncaught = .               if `var'hu_noncaught != `var'wi_noncaught & statehu != . &  statewi != .
}


save BDDPanel3, replace	



******* DATA FOR ANALYSIS OF COUPLES WHERE BOTH ARE OBSERVED

*** Goal: keep one observation per couple, only where information is consistent


drop reg_cilw regeg_cilw reg_cilw_bef1 reg_cilw_noncaught regeg_cilw_bef1 regeg_cilw_noncaught
gen reg_cilw        = reg_cilwhu     if reg_cilwwi   == reg_cilwhu      
gen regeg_cilw      = regeg_cilwhu   if regeg_cilwwi == regeg_cilwhu     

gen reg_cilw_bef1         = reg_cilwhu_bef1          if reg_cilwwi_bef1         == reg_cilwhu_bef1     
gen reg_cilw_noncaught    = reg_cilwhu_noncaught     if reg_cilwwi_noncaught    == reg_cilwhu_noncaught     
gen regeg_cilw_bef1       = regeg_cilwhu_bef1        if regeg_cilwwi_bef1       == regeg_cilwhu_bef1       
gen regeg_cilw_noncaught  = regeg_cilwhu_noncaught   if regeg_cilwwi_noncaught  == regeg_cilwhu_noncaught      



foreach v in d_1y d_2y d_3y d_4y d_5y d_6y d_7y d_8y d_9y d_10y  d_1y_c d_2y_c d_3y_c d_4y_c d_5y_c d_6y_c d_7y_c d_8y_c d_9y_c d_10y_c y_1994_c /*
*/ y_1995_c y_1996_c y_1997_c y_1998_c y_1999_c y_2000_c y_2001_c y_2002_c y_2003_c y_2004_c y_2005_c y_2006_c y_2007_c y_2008_c y_2009_c y_2010_c y_2011_c prov_TN_child /*
*/ prov_PEI_child prov_NE_child prov_NB_child prov_ONT_child prov_MAN_child prov_SAS_child prov_ALB_child prov_CB_child {

gen `v' = (`v'_hu ==1)  if  `v'_wi == `v'_hu 

}


save BDDPanel4, replace	


exit 



